@@ -21,6 +21,7 @@ from yellowdog_client import PlatformClient
 from yellowdog_client.common.json import Json
 from yellowdog_client.model import (
     Allowance,
+    Application,
     BestComputeSourceReport,
     BestComputeSourceReportSource,
     ComputeRequirement,
@@ -30,7 +31,10 @@ from yellowdog_client.model import (
     ComputeRequirementTemplateUsage,
     ComputeSourceTemplateSummary,
     ConfiguredWorkerPool,
+    ExternalUser,
+    Group,
     Instance,
+    InternalUser,
     KeyringSummary,
     MachineImageFamilySummary,
     NamespacePolicy,
@@ -39,8 +43,10 @@ from yellowdog_client.model import (
     ObjectPath,
     ProvisionedWorkerPool,
     ProvisionedWorkerPoolProperties,
+    Role,
     Task,
     TaskGroup,
+    User,
     Worker,
     WorkerPoolSummary,
     WorkRequirement,
@@ -709,6 +715,115 @@ def namespace_policies_table(
     return headers, table
 
 
+def users_table(
+    users: List[User],
+) -> (List[str], List[List]):
+    headers = [
+        "#",
+        "Name",
+        "User Type",
+        "Username",
+        "Email",
+        "ID",
+    ]
+    table = []
+    for index, user in enumerate(users):
+        if isinstance(user, InternalUser):
+            table.append(
+                [
+                    index + 1,
+                    user.name,
+                    "Internal",
+                    user.username,
+                    user.email,
+                    user.id,
+                ]
+            )
+        elif isinstance(user, ExternalUser):  # External user
+            table.append(
+                [
+                    index + 1,
+                    user.name,
+                    "External",
+                    "",
+                    user.email,
+                    user.id,
+                ]
+            )
+    return headers, table
+
+
+def applications_table(
+    applications: List[Application],
+) -> (List[str], List[List]):
+    headers = [
+        "#",
+        "Name",
+        "Description",
+        "ID",
+    ]
+    table = []
+    for index, application in enumerate(applications):
+        table.append(
+            [
+                index + 1,
+                application.name,
+                application.description,
+                application.id,
+            ]
+        )
+    return headers, table
+
+
+def groups_table(
+    groups: List[Group],
+) -> (List[str], List[List]):
+    headers = [
+        "#",
+        "Name",
+        "Admin Group?",
+        "Description",
+        "Roles",
+        "ID",
+    ]
+    table = []
+    for index, group in enumerate(groups):
+        table.append(
+            [
+                index + 1,
+                group.name,
+                group.adminGroup,
+                f"{group.description[:40] + '...' if len(group.description) > 40 else group.description}",
+                ", ".join([x.role.name for x in group.roles]),
+                group.id,
+            ]
+        )
+    return headers, table
+
+
+def roles_table(
+    roles: List[Role],
+) -> (List[str], List[List]):
+    headers = [
+        "#",
+        "Name",
+        "Permissions",
+        "ID",
+    ]
+    table = []
+    for index, role in enumerate(roles):
+        permissions = ", ".join(sorted([x.value for x in role.permissions]))
+        table.append(
+            [
+                index + 1,
+                role.name,
+                f"{permissions[:40] + '...' if len(permissions) > 40 else permissions}",
+                role.id,
+            ]
+        )
+    return headers, table
+
+
 def print_numbered_object_list(
     client: PlatformClient,
     objects: List[Union[Item, str, Dict]],
@@ -769,6 +884,14 @@ def print_numbered_object_list(
         headers, table = nodes_table(objects)
     elif isinstance(objects[0], Worker):
         headers, table = workers_table(objects)
+    elif isinstance(objects[0], User):
+        headers, table = users_table(objects)
+    elif isinstance(objects[0], Application):
+        headers, table = applications_table(objects)
+    elif isinstance(objects[0], Group):
+        headers, table = groups_table(objects)
+    elif isinstance(objects[0], Role):
+        headers, table = roles_table(objects)
     else:
         table = []
         for index, obj in enumerate(objects):
@@ -1156,9 +1279,9 @@ STATUS_COUNTS_INSTANCES = [
 
 STATUS_COUNTS_WORKERS = [
     StatusCount("DOING_TASK", True),
-    StatusCount("SLEEPING", True),
     StatusCount("STOPPED", True),
-    StatusCount("STARTING", True),
+    StatusCount("SLEEPING"),  # Should no longer see this state
+    StatusCount("STARTING"),
     StatusCount("LATE"),
     StatusCount("FOUND"),
     StatusCount("LOST"),
